@@ -60,7 +60,7 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="148"/>
         <source>LXQt Session Suspend</source>
-        <translation>Hviletilstand af LXQt-session</translation>
+        <translation>LXQt-session i hviletilstand</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="149"/>
@@ -70,7 +70,7 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>LXQt Session Hibernate</source>
-        <translation>LXQt Session Dvale</translation>
+        <translation>LXQt-session i dvaletilstand</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="159"/>
@@ -100,7 +100,7 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>LXQt Session Logout</source>
-        <translation>Udlogning af LXQt-session</translation>
+        <translation>Log ud fra LXQt-session</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="189"/>
@@ -129,7 +129,7 @@
     <message>
         <location filename="../lxqtscreensaver.cpp" line="161"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation>Kunne ikke køre &quot;%1&quot;. Sørg for at du har en låser/pauseskærm som er installeret og kører som er kompatibel med xdg-screensaver.</translation>
+        <translation>Kunne ikke køre &quot;%1&quot;. Sørg for at du har en låser/pauseskærm installeret og kørende som er kompatibel med xdg-screensaver.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="165"/>
@@ -167,7 +167,7 @@
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
-        <translation>QDBusInterface er ugyldig</translation>
+        <translation>QDBusInterface er ugyldigt</translation>
     </message>
     <message>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
