@@ -6,7 +6,7 @@
     <message>
         <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
         <source>Dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>ඩයලොග්</translation>
     </message>
 </context>
 <context>
@@ -14,12 +14,12 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>LXQt Power Manager Error</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt විදුලි කළමනාකරණ දෝෂය</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>Hibernate failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>හයිබනේට් අසාර්ථක විය.</translation>
     </message>
 </context>
 <context>
@@ -27,7 +27,7 @@
     <message>
         <location filename="../lxqtnotification.cpp" line="161"/>
         <source>Notifications Fallback</source>
-        <translation type="unfinished"></translation>
+        <translation>දැනුම්දීමේ ෆෝල්බැක්</translation>
     </message>
 </context>
 <context>
@@ -35,93 +35,93 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="108"/>
         <source>Hibernate</source>
-        <translation type="unfinished"></translation>
+        <translation>හයිබනේට්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="115"/>
         <source>Suspend</source>
-        <translation type="unfinished"></translation>
+        <translation>සස්පෙන්ඩ්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="122"/>
         <source>Reboot</source>
-        <translation type="unfinished"></translation>
+        <translation>රීබූට්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="129"/>
         <source>Shutdown</source>
-        <translation type="unfinished"></translation>
+        <translation>ශට්ඩවුන්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="136"/>
         <source>Logout</source>
-        <translation type="unfinished"></translation>
+        <translation>ලොගාවුට්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="148"/>
         <source>LXQt Session Suspend</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt සැසිය සස්පෙන්ඩ්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="149"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
-        <translation type="unfinished"></translation>
+        <translation>ඔබට පරිගණකය සස්පෙන්ඩ් කිරිමට අවශ්‍ය බව විශ්වාසද?&lt;p&gt;පරිගණකය බලශක්ති සුරකුම් තත්වයට ගෙනයයි. විදුලිය අහිමි වීමකදී පද්ධති තත්ත්වය සුරැකෙන්නේ නැත.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>LXQt Session Hibernate</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt සැසිය හයිබනේට්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="159"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
-        <translation type="unfinished"></translation>
+        <translation>ඔබට පරිගණකය හයිබනේට් කිරිමට අවශ්‍ය බව විශ්වාසද?&lt;p&gt;පරිගණකය බලශක්ති සුරකුම් තත්වයට ගෙනයයි. විදුලිය අහිමි වූවත් පද්ධති තත්ත්වය සුරැකී පවති.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>LXQt Session Reboot</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt සැසිය රීබූට්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="169"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
-        <translation type="unfinished"></translation>
+        <translation>ඔබට පරිගණකය නැවත පණගැනිවීමට අවශ්‍ය බව විශ්වාසද? සුරකා නොමැති සියලු කාර්යයන් අහිමි වනු ඇත...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>LXQt Session Shutdown</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt සැසිය ශට්ඩවුන්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="179"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
-        <translation type="unfinished"></translation>
+        <translation>ඔබට පරිගණකය ක්‍රියාවිරහිත කරන්න අවශ්‍ය බව විශ්වාසද? සුරකා නොමැති සියලු කාර්යයන් අහිමි වනු ඇත...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>LXQt Session Logout</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt සැසිය ලොගාවුට්</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="189"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
-        <translation type="unfinished"></translation>
+        <translation>ඔබට ලොගාවුට් වීමට අවශ්‍ය බව විශ්වාසද? සුරකා නොමැති සියලු කාර්යයන් අහිමි වනු ඇත...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="197"/>
         <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>LXQt Power Manager Error</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt විදුලි කළමනාකරණ දෝෂය</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="197"/>
         <source>Hibernate failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>හයිබනේට් අසාර්ථක විය.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>Suspend failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>සස්පෙන්ඩ් අසාර්ථක විය.</translation>
     </message>
 </context>
 <context>
@@ -129,22 +129,22 @@
     <message>
         <location filename="../lxqtscreensaver.cpp" line="161"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ධාවනය කල නොහැකි විය. xdg-screensaver සමඟ ගැළපෙන අගුලක්/ස්ක්‍රින්සේවරයක් ස්ථාපනය කර ක්‍රියාත්මක වන බවට වග බලා ගන්න.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="165"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ධාවනය කල නොහැකි විය. මෙම අගුල/ස්ක්‍රින්සේවරය ස්ථාපනය කර ක්‍රියාත්මක වන බවට වග බලා ගන්න.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="243"/>
+        <location filename="../lxqtscreensaver.cpp" line="247"/>
         <source>Lock Screen</source>
-        <translation type="unfinished"></translation>
+        <translation>අගුලු තිරය</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="156"/>
         <source>Screen Saver Error</source>
-        <translation type="unfinished"></translation>
+        <translation>ස්ක්‍රින්සේවර් දෝෂය</translation>
     </message>
 </context>
 <context>
@@ -152,7 +152,7 @@
     <message>
         <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="47"/>
         <source>Choose the page to be shown.</source>
-        <translation type="unfinished"></translation>
+        <translation>පෙන්විය යුතු පිටුව තෝරන්න.</translation>
     </message>
 </context>
 <context>
@@ -161,19 +161,19 @@
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
         <source>Power Manager Error</source>
-        <translation type="unfinished"></translation>
+        <translation>විදුලි කළමනාකරණ දෝෂය</translation>
     </message>
     <message>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>QDBusInterface ය අවලංගුය</translation>
     </message>
     <message>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
-        <translation type="unfinished"></translation>
+        <translation>විදුලි කළමනාකරණ දෝෂය (D-BUS කෝල්)</translation>
     </message>
 </context>
 </TS>
